@@ -1,3 +1,4 @@
+from typing import Union
 from pathlib import Path
 import os
 
@@ -10,6 +11,12 @@ credentials = service_account.Credentials.from_service_account_file(os.environ['
 client = storage.Client(project=os.environ['GCLOUD_PROJECT'], credentials=credentials)
 
 
+def set_gcp_creds(project_name: str, path_to_creds: Union[Path, str]) -> storage.Client:
+    credentials = service_account.Credentials.from_service_account_file(path_to_creds)
+    client = storage.Client(project=project_name, credentials=credentials)
+    return client
+
+
 def list_blobs_with_prefix(bucket_name, prefix, delimiter=None, client=client):
     # Note: Client.list_blobs requires at least package version 1.17.0.
     blobs = client.list_blobs(
@@ -36,4 +43,4 @@ def download_gs_folder(bucket, gs_path, dst_path, client=client):
         print(f'Downloading: {fname}')
         print(f'To: {dst}')
         download_blob(blob, dst, client=client)
-    print("DONE")
\ No newline at end of file
+    print("DONE")
